summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorGreg Roach <fisharebest@gmail.com>2015-09-27 09:40:09 +0100
committerGreg Roach <fisharebest@gmail.com>2015-09-27 09:40:09 +0100
commit71eba38559d3b0e2e10fe4b446ef4429bb84f175 (patch)
tree3c0d1d3baebfb230e70f5575e19e884cc248d115 /tests
parent8e2171fe0219e8c030e0832b6bca4eb535e71337 (diff)
downloadwebtrees-71eba38559d3b0e2e10fe4b446ef4429bb84f175.tar.gz
webtrees-71eba38559d3b0e2e10fe4b446ef4429bb84f175.tar.bz2
webtrees-71eba38559d3b0e2e10fe4b446ef4429bb84f175.zip
Unit tests
Diffstat (limited to 'tests')
-rw-r--r--tests/app/Census/CensusColumnMonthIfBornWithinYearTest.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/app/Census/CensusColumnMonthIfBornWithinYearTest.php b/tests/app/Census/CensusColumnMonthIfBornWithinYearTest.php
index 7ee6e0e019..3422effe0e 100644
--- a/tests/app/Census/CensusColumnMonthIfBornWithinYearTest.php
+++ b/tests/app/Census/CensusColumnMonthIfBornWithinYearTest.php
@@ -24,9 +24,9 @@ use Fisharebest\Webtrees\Individual;
use Mockery;
/**
* Test harness for the class CensusColumnMonthIfBornwithinYear
*/
-class CensusColumnMonthIfBornwithinYearTest extends \PHPUnit_Framework_TestCase {
+class CensusColumnMonthIfBornWithinYearTest extends \PHPUnit_Framework_TestCase {
/**
* Delete mock objects
*/
@@ -35,7 +35,7 @@ class CensusColumnMonthIfBornwithinYearTest extends \PHPUnit_Framework_TestCase
}
/**
- * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornwithinYear
+ * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornWithinYear
* @covers Fisharebest\Webtrees\Census\AbstractCensusColumn
*/
public function testBornWithinYear() {
@@ -45,13 +45,13 @@ class CensusColumnMonthIfBornwithinYearTest extends \PHPUnit_Framework_TestCase
$census = Mockery::mock(CensusInterface::class);
$census->shouldReceive('censusDate')->andReturn('01 JUN 1860');
- $column = new CensusColumnMonthIfBornwithinYear($census, '', '');
+ $column = new CensusColumnMonthIfBornWithinYear($census, '', '');
$this->assertSame('Jan', $column->generate($individual));
}
/**
- * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornwithinYear
+ * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornWithinYear
* @covers Fisharebest\Webtrees\Census\AbstractCensusColumn
*/
public function testNotBornWithinYear() {
@@ -61,13 +61,13 @@ class CensusColumnMonthIfBornwithinYearTest extends \PHPUnit_Framework_TestCase
$census = Mockery::mock(CensusInterface::class);
$census->shouldReceive('censusDate')->andReturn('01 JUN 1860');
- $column = new CensusColumnMonthIfBornwithinYear($census, '', '');
+ $column = new CensusColumnMonthIfBornWithinYear($census, '', '');
$this->assertSame('', $column->generate($individual));
}
/**
- * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornwithinYear
+ * @covers Fisharebest\Webtrees\Census\CensusColumnMonthIfBornWithinYear
* @covers Fisharebest\Webtrees\Census\AbstractCensusColumn
*/
public function testNoBirth() {
@@ -77,7 +77,7 @@ class CensusColumnMonthIfBornwithinYearTest extends \PHPUnit_Framework_TestCase
$census = Mockery::mock(CensusInterface::class);
$census->shouldReceive('censusDate')->andReturn('01 JUN 1860');
- $column = new CensusColumnMonthIfBornwithinYear($census, '', '');
+ $column = new CensusColumnMonthIfBornWithinYear($census, '', '');
$this->assertSame('', $column->generate($individual));
}
@@ -24,9 +24,9 @@ use Fisharebest\Webtrees\Individual;
use Mockery;
/**
- * Test harness for the class CensusColumnMonthIfBornwithinYear
+ * Test harness for the class CensusColumnMonthIfBornWithinYear
*/